package uicc.contactmanager.examples;

import uicc.contactmanager.ContactManager;
import uicc.contactmanager.ContactView;
import uicc.contactmanager.ContactsListView;
import uicc.contactmanager.FieldDescriptorView;
import uicc.contactmanager.FieldDescriptorsListView;
import uicc.contactmanager.FieldView;
import uicc.contactmanager.GroupView;
import uicc.contactmanager.GroupsListView;

class ExampleOfUse {

    ContactView contact;
    ContactsListView contactsList;
    FieldView field;
    FieldDescriptorsListView fieldDescriptorsList;
    FieldDescriptorView fieldDescriptor;
    GroupsListView groupsList;
    GroupView group;
    int name,tel1,tel2,email;
    
    ExampleOfUse()
    {
        //During application installation, the application creates and stores all necessary objects to use during application runtime.
        //get an instance of the Contact Manager:
        ContactManager contactManager = ContactManager.getContactManager();

        //create an instance of the Contacts list:
        contactsList = contactManager.createContactsListViewInstance();

        //create an instance of the Fields Descriptors list:
        fieldDescriptorsList = contactManager.createFieldDescriptorsListViewInstance();

        //create an instance of the Groups List:
        groupsList = contactManager.createGroupsListViewInstance();

        //create a contact instance for contacts enumeration:
        contact = contactsList.createContactViewInstance();

        //create a field object for fields enumeration:
        field = contact.createFieldInstance();

        //create group object for objects enumeration:
        group = groupsList.createGroupViewInstance();

        //create field descriptor object for fields descriptors enumeration:
        fieldDescriptor = fieldDescriptorsList.createFieldDescriptorViewInstance() ;

        /*************************************
         * Application could also define if needed 
         * a contact structure by creating a basic 
         * field description
         *************************************/
        byte[] sampleLabel = new byte[] {'s','a','m','p','l','e'}; 

        //create name field:
        fieldDescriptor.setType(FieldView.TYPE_NAME) ;
        fieldDescriptor.setAttributes(FieldView.ATTR_ANY) ;
        fieldDescriptor.setLabel(sampleLabel, (short)0, (short)sampleLabel.length);
        name = fieldDescriptorsList.addFieldDescriptor(fieldDescriptor) ;

        //create home phone number field:
        fieldDescriptor.setType(FieldView.TYPE_TEL);
        fieldDescriptor.setAttributes(FieldView.ATTR_HOME);
        fieldDescriptor.setLabel(sampleLabel, (short)0, (short)sampleLabel.length);
        tel1 = fieldDescriptorsList.addFieldDescriptor(fieldDescriptor);

        //create cell and work phone number field:
        fieldDescriptor.setType(FieldView.TYPE_TEL) ;
        fieldDescriptor.setAttributes(FieldView.ATTR_WORK|FieldView.ATTR_CELL) ;
        fieldDescriptor.setLabel(sampleLabel, (short)0, (short)sampleLabel.length);
        tel2 = fieldDescriptorsList.addFieldDescriptor(fieldDescriptor) ;

        //create email field:
        fieldDescriptor.setType(FieldView.TYPE_EMAIL);
        fieldDescriptor.setAttributes(FieldView.ATTR_ANY);
        fieldDescriptor.setLabel(sampleLabel, (short)0, (short)sampleLabel.length);
        email = fieldDescriptorsList.addFieldDescriptor(fieldDescriptor);
    }

    void listAllContacts()
    {
        //The ContactsList class allows the management of all phonebook contacts:
        //List all contact:
        contactsList.startEnumeration();
        while(contactsList.hasMoreContacts())
        {
            contactsList.selectNextContact(contact) ;
            //.....
        }
    }

    void findSpecificContact()
    {
        //Find a contact with specific value. 
        //Find a contact with phone number that ends with "0603"
        byte pattern[] = {'*','0','6','0','3'} ;
        contactsList.startEnumeration(FieldView.TYPE_TEL, FieldView.ATTR_ANY, 
                pattern, (short)0, (short)pattern.length);
        contactsList.selectNextContact(contact);
    }

    void createDeleteContact()
    {
        //Create a Contact
        contactsList.addContact(contact) ;
        int contactId = contact.getContactIdentifier();

        //Delete a contact
        contactsList.removeContact(contactId);
    }

    void readContact()
    {
        // The Contact object provides access to contact fields. 
        //Read fields of a contact
        byte buffer[] = new byte[60];
        contact.startEnumeration() ;
        while(contact.hasMoreFields())
        {
            contact.selectNextField(field) ;
            switch(field.getType())
            {
            case FieldView.TYPE_TEL:
                field.readPhoneNumber(buffer, (short)0, 
                        (short)buffer.length); 
                break;
            case FieldView.TYPE_NAME:
                // get family name
                field.readFormattedName(FieldView.NAME_FAMILY,buffer, 
                        (short)0, (short)buffer.length);
                break;
            default:
                field.readBinary(buffer, (short)0, 
                        (short)buffer.length);
            }
        }
    }

    void updateField()
    {
        //Update a field

        //Update email of the contact
        contact.selectField(field, email) ;

        //or

        contact.startEnumeration(FieldView.TYPE_EMAIL, FieldView.ATTR_ANY, null, (short)0, (short)0) ;
        contact.selectNextField(field) ;
        // then update
        byte newMail[] = {'j','o','e','@','g','o','.','c','o','m'};
        field.updateBinary(newMail, (short)0, (short)newMail.length) ;
    }

    void addAGroup()
    {
        //Create a group
        byte group1[]={'g','r','o','u','p','1'} ;

        // add new group
        int groupId = groupsList.addGroup(group1, (short)0, (short)group1.length);

        //Delete a group
        groupsList.removeGroup(groupId) ;

        //Add a contact to the group
        group.addContact(contact) ;

        // remove contact from a group
        group.removeContact(contact.getContactIdentifier()) ;

        //Enumerate all groups
        groupsList.startEnumeration() ;
        while(groupsList.hasMoreGroups())
        {
            groupsList.selectNextGroup(group);
            //....
        }
        //Enumerate all groups of a contact
        groupsList.startEnumeration(contact.getContactIdentifier()) ;
        while(groupsList.hasMoreGroups())
        {
            groupsList.selectNextGroup(group);
            //....
        }
    }
}